envie

Struct Envie

pub struct Envie {
    pub variables: HashMap<String, String>,
}

Fields

variables: HashMap<String, String>

Implementations

Source

impl Envie

pub fn load() -> Result<Self, String>

Load .env file from the current directory and parse it into a new Envie instance.

pub fn load_with_path(path: &str) -> Result<Self, String>

Load a .env file from a specified path and parse it into a new Envie instance.

pub fn reload(&mut self) -> Result<(), String>

Reload the .env file from the current directory.

pub fn get(&self, key: &str) -> Option<String>

Get a value by key.

pub fn get_bool(&self, key: &str) -> Result<bool, String>

Get a value as a boolean.

pub fn get_int(&self, key: &str) -> Result<i32, String>

Get a value as an integer.

pub fn get_f64(&self, key: &str) -> Result<f64, String>

Get a value as a float (f64).

pub fn contains_key(&self, key: &str) -> bool

Check if a key exists in the environment variables.

pub fn get_all(&self) -> HashMap<String, String>

Get all environment variables as a HashMap.

pub fn set(&mut self, key: &str, value: &str) -> Result<(), String>

Set a value for a given key and update the .env file.

pub fn remove(&mut self, key: &str) -> Result<(), String>

Remove a key-value pair and update the .env file.

pub unsafe fn set_system_env( &mut self, key: &str, value: &str, ) -> Result<(), String>

Set and apply the variable to the system environment

pub unsafe fn export_to_system_env(&self) -> Result<(), String>

Export all loaded variables to the system environment.