envie

Struct Envie

pub struct Envie {
    pub variables: HashMap<String, String>,
}

Fields

variables: HashMap<String, String>

Implementations

Source

impl Envie

pub fn load() -> Result<Self, String>

Load .env file and parse it into a new Envie instance.

pub fn get(&self, key: &str) -> Option<String>

Get a value by key.

pub fn get_bool(&self, key: &str) -> Result<bool, String>

Get a value as a boolean.

pub fn get_int(&self, key: &str) -> Result<i32, String>

Get a value as an integer.

pub fn get_all(&self) -> HashMap<String, String>

Get all environment variables as a HashMap.

pub fn set(&mut self, key: &str, value: &str) -> Result<(), String>

Set a value for a given key and update the .env file.

pub fn remove(&mut self, key: &str) -> Result<(), String>

Remove a key-value pair and update the .env file.